BlePeripheralDescriptor class
Peripheral/GATT server descriptor model that reuses BleDescriptor.
- Inheritance
-
- Object
- BleDescriptor
- BlePeripheralDescriptor
Constructors
-
BlePeripheralDescriptor({required String uuid, Uint8List? value, List<
PeripheralAttributePermission> ? permissions}) -
BlePeripheralDescriptor.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
permissions
↔ List<
PeripheralAttributePermission> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid ↔ String
-
getter/setter pairinherited
- value ↔ Uint8List?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toPeripheralDescriptor(
) → PeripheralDescriptor -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited