LedgerDevice class

Annotations

Constructors

LedgerDevice({required String id, required String name, required ConnectionType connectionType, required LedgerDeviceType deviceInfo, int rssi = 0})
const
LedgerDevice.ble({required String id, required String name, required LedgerDeviceType deviceInfo, int rssi = 0})
factory
LedgerDevice.usb(UsbDevice device)
factory

Properties

connectionType ConnectionType
final
deviceInfo LedgerDeviceType
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
name String
final
rssi int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String id()?, String name()?, ConnectionType connectionType()?, int rssi()?, LedgerDeviceType deviceInfo()?}) LedgerDevice
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override