LedgerGattReader class

Constructors

LedgerGattReader()

Properties

currentSequence int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
payload List<int>
getter/setter pair
remainingBytes int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscription StreamSubscription?
getter/setter pair

Methods

close() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(Stream<List<int>> stream, {required void onData(Uint8List event), required void onError(Object exception)}) → void
reset() → void
Reset the reader
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

dataCla → const int
The APDU command tag 0x05 is used to transfer application specific data.
mtuCla → const int
The GET MTU command tag 0x08 is used to query the negociated MTU and optimize the size of fragments
versionCla → const int
The GET VERSION command tag 0x00 is used to query the current version of the protocol being used