versionCla constant
int
const versionCla
The GET VERSION command tag 0x00 is used to query the current version of the protocol being used
Implementation
static const versionCla = 0x00;
The GET VERSION command tag 0x00 is used to query the current version of the protocol being used
static const versionCla = 0x00;