PlatformConfig class

Platform specific config to scan devices

If more than 1 platform supports a certain parameter then it should be in the high level APIs instead of platform specific options.

Constructors

PlatformConfig({WebOptions? web, AndroidOptions? android})

Properties

android AndroidOptions?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
web WebOptions?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited