LedgerRawOperation<T> class abstract

Implementers

Constructors

LedgerRawOperation()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(ByteDataReader reader) → Future<T>
The Packet sequence index describes the current sequence for fragmented payloads. The first fragment index is 0x00 and increased in following packets.
stripApduHeader(Uint8List data) → Uint8List
toString() → String
A string representation of this object.
inherited
write(ByteDataWriter writer) → Future<List<Uint8List>>
The Packet sequence index describes the current sequence for fragmented payloads. The first fragment index is 0x00 and increased in following packets.

Operators

operator ==(Object other) → bool
The equality operator.
inherited