LedgerSimpleOperation class

Inheritance

Constructors

LedgerSimpleOperation({required int cla, required int ins, required int p1, required int p2, required Uint8List data, required bool prependDataLength, String? debugName})

Properties

cla → int
final
data → Uint8List
final
debugName ↔ String
latefinal
hashCode → int
The hash code for this object.
no setterinherited
ins → int
final
p1 → int
final
p2 → int
final
prependDataLength → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(ByteDataReader reader) → Future<ByteDataReader>
The Packet sequence index describes the current sequence for fragmented payloads. The first fragment index is 0x00 and increased in following packets.
override
stripApduHeader(Uint8List data) → Uint8List
inherited
toString() → String
A string representation of this object.
inherited
write(ByteDataWriter writer) → Future<List<Uint8List>>
The Packet sequence index describes the current sequence for fragmented payloads. The first fragment index is 0x00 and increased in following packets.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited