LedgerDeviceException class
- Inheritance
-
- Object
- LedgerException
- LedgerDeviceException
Constructors
- LedgerDeviceException({String message = "", Object? cause, int errorCode = 0x6F00, required ConnectionType connectionType})
Properties
- cause → Object?
-
final
- connectionType → ConnectionType
-
final
- errorCode → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited