LedgerInterface class sealed
Properties
-
devices
→ Future<
List< LedgerDevice> > -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
status
→ Future<
AvailabilityState> -
no setter
-
statusStateChanges
→ Stream<
AvailabilityState> -
no setter
Methods
-
connect(
LedgerDevice device) → Future< LedgerConnection> -
deviceStateChanges(
String deviceId) → Stream< BleConnectionState> -
dispose(
{dynamic onError(LedgerException)?}) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scan(
) → Stream< LedgerDevice> -
stopScanning(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
ble(
{required PermissionRequestCallback onPermissionRequest, BluetoothOptions? bleOptions}) → LedgerInterface -
usb(
) → LedgerInterface